==> legato-dist-wps-1.4.0-dist.tar.gz: Legato-WPS-1.4.0/lib/WPS/I18n/Messages/en.js <==
/*
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

WPS.I18n.Messages.dictionaries.en['WPS.AbstractGeometry.Select'] = "Select the geometry. Please select the layer before selecting the geometry.";
WPS.I18n.Messages.dictionaries.en['WPS.AbstractGeometry.InvalidSelectionGeometryType'] = "Your selection has the type [${invalidGeometryType}]. Expected is [${validGeometryType}].";
WPS.I18n.Messages.dictionaries.en['WPS.Point.Draw'] = "Draws a point.";
WPS.I18n.Messages.dictionaries.en['WPS.Point.Edit'] = "Edits the point.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiPoint.Draw'] = "Draws a multi point.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiPoint.Edit'] = "Edits the multi point.";
WPS.I18n.Messages.dictionaries.en['WPS.LineString.Draw'] = "Draws a line string.";
WPS.I18n.Messages.dictionaries.en['WPS.LineString.Edit'] = "Edits the line string.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiLineString.Draw'] = "Draws a multi line string.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiLineString.Edit'] = "Edits the multi line string.";
WPS.I18n.Messages.dictionaries.en['WPS.Polygon.Draw'] = "Draws a polygon.";
WPS.I18n.Messages.dictionaries.en['WPS.Polygon.Edit'] = "Edits the polygon.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiPolygon.Draw'] = "Draws a multi polygon.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiPolygon.Edit'] = "Edits the multi polygon.";
WPS.I18n.Messages.dictionaries.en['WPS.ProcessSelector.Title'] = "Process Selection";
WPS.I18n.Messages.dictionaries.en['WPS.ProcessSelector.Description'] = "Web Processing Services (WPS) extend the functionality of GISterm with services provided centrally. Please choose a WPS service.";
WPS.I18n.Messages.dictionaries.en['WPS.Model.MustFill'] = "${title} must be filled.";
WPS.I18n.Messages.dictionaries.de['WPS.Result.ExecutionContext.ResultLayerName'] = "Current geomtry";
WPS.I18n.Messages.dictionaries.de['WPS.Result.ExecutionContext.MarkerLayerName'] = "Current marker";

==> legato-dist-wps-2.0.0-dist.tar.gz: Legato-WPS-2.0.0/lib/WPS/I18n/Messages/en.js <==
/*
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

WPS.I18n.Messages.dictionaries.en = Legato.I18n.Messages.dictionaries.en;

WPS.I18n.Messages.dictionaries.en['WPS.AbstractGeometry.Select'] = "Select the geometry. Please select the layer before selecting the geometry.";
WPS.I18n.Messages.dictionaries.en['WPS.AbstractGeometry.InvalidMultiGeometryType'] = "Please create geometries lying nearby. Choosing separate geometries is not possible.";
WPS.I18n.Messages.dictionaries.en['WPS.AbstractGeometry.InvalidSelectionGeometryType'] = "Your selection has the type [${invalidGeometryType}]. Expected is [${validGeometryType}].";
WPS.I18n.Messages.dictionaries.en['WPS.Point.Draw'] = "Draws a point.";
WPS.I18n.Messages.dictionaries.en['WPS.Point.Edit'] = "Edits the point.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiPoint.Draw'] = "Draws a multi point.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiPoint.Edit'] = "Edits the multi point.";
WPS.I18n.Messages.dictionaries.en['WPS.LineString.Draw'] = "Draws a line string.";
WPS.I18n.Messages.dictionaries.en['WPS.LineString.Edit'] = "Edits the line string.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiLineString.Draw'] = "Draws a multi line string.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiLineString.Edit'] = "Edits the multi line string.";
WPS.I18n.Messages.dictionaries.en['WPS.Polygon.Draw'] = "Draws a polygon.";
WPS.I18n.Messages.dictionaries.en['WPS.Polygon.Edit'] = "Edits the polygon.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiPolygon.Draw'] = "Draws a multi polygon.";
WPS.I18n.Messages.dictionaries.en['WPS.MultiPolygon.Edit'] = "Edits the multi polygon.";
WPS.I18n.Messages.dictionaries.en['WPS.ProcessSelector.Title'] = "Process Selection";
WPS.I18n.Messages.dictionaries.en['WPS.ProcessSelector.Description'] = "Web Processing Services (WPS) are functional geo-services provided centrally. Please choose a WPS service.";
WPS.I18n.Messages.dictionaries.en['WPS.ProcessSelector.ProcessSelectionInfoTextDescription'] = "Description:";
WPS.I18n.Messages.dictionaries.en['WPS.Model.MustFill'] = "${title} must be filled.";
WPS.I18n.Messages.dictionaries.en['WPS.Result.ExecutionContext.ResultLayerName'] = "Current geomtry";
WPS.I18n.Messages.dictionaries.en['WPS.Result.ExecutionContext.MarkerLayerName'] = "Current marker";
WPS.I18n.Messages.dictionaries.en['WPS.Button.OK'] = "OK";
WPS.I18n.Messages.dictionaries.en['WPS.Button.Cancel'] = "Cancel";
WPS.I18n.Messages.dictionaries.en['WPS.Button.Back'] = "Back";
